@@ -3,7 +3,7 @@
 package App::WHMCSUtils;
 
 our $DATE = '2019-09-19'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -719,7 +719,7 @@ sub _login_admin {
 }
 
 sub _send_verification_email {
-    my ($args, $client_rec) = @_;
+    my ($args, $client_rec, $dbh, $orig_sender_email, $sender_email) = @_;
 
     _login_admin(%$args);
 
@@ -730,6 +730,7 @@ sub _send_verification_email {
 
     my $content = $mech->content;
     $content =~ /'token':\s*'(\w+)'/ or die "Can't extract submit token";
+    $dbh->do("UPDATE tblconfiguration SET value=? WHERE setting='Email'", {}, $sender_email) if $sender_email ne $orig_sender_email;
     $mech->post(
         $url0,
         [
@@ -740,6 +741,7 @@ sub _send_verification_email {
     );
     die "Can't post to $url1 to submit resend action: " .
         $mech->status unless $mech->success;
+    $dbh->do("UPDATE tblconfiguration SET value=? WHERE setting='Email'", {}, $orig_sender_email) if $sender_email ne $orig_sender_email;
 }
 
 $SPEC{send_verification_emails} = {
@@ -771,6 +773,10 @@ _
             schema => 'bool*',
             default => 1,
         },
+        limit => {
+            summary => 'Only process this many clients then stop',
+            schema => 'uint*',
+        },
         include_client_ids => {
             #'x.name.is_plural' => 1,
             #'x.name.singular' => 'include_client_id',
@@ -821,8 +827,8 @@ sub send_verification_emails {
         join("",
              "SELECT id,firstname,lastname,companyname,email FROM tblclients ",
              "WHERE email_verified=0 ",
-             (defined $args{include_active}   && !$args{include_active}   ? "" : "AND status <> 'Active' "  ),
-             (defined $args{include_inactive} && !$args{include_inactive} ? "" : "AND status <> 'Inactive' "),
+             (defined $args{include_active}   && !$args{include_active}   ? "AND status <> 'Active' "   : ""),
+             (defined $args{include_inactive} && !$args{include_inactive} ? "AND status <> 'Inactive' " : ""),
              ($args{include_client_ids} ? "AND id IN (".join(",",map{$_+0} @{ $args{include_client_ids} }).")" : ""),
              "ORDER BY ".($args{random} ? "RAND()" : "id"),
          ),
@@ -845,6 +851,10 @@ sub send_verification_emails {
 
     for my $client_rec (@client_recs) {
         $i++;
+        if ($args{limit} && $i > $args{limit}) {
+            log_info "Terminating because limit is set to %d", $args{limit};
+            last;
+        }
         my $sender_email = $orig_sender_email;
         if ($args{hook_set_sender_email}) {
             unless (ref $args{hook_set_sender_email} eq 'CODE') {
@@ -852,7 +862,6 @@ sub send_verification_emails {
                 die "Can't compile code in hook_set_sender_email: $@" if $@;
             }
             $sender_email = $args{hook_set_sender_email}->($client_rec, $orig_sender_email);
-            $dbh->do("UPDATE tblconfiguration SET value=? WHERE setting='Email'", {}, $sender_email);
         }
         log_info "[%d/%d]%s Sending verification email (sender email %s) for client #%d (%s %s, email %s) ...",
             $i, scalar(@client_recs),
@@ -860,12 +869,9 @@ sub send_verification_emails {
             $sender_email,
             $client_rec->{id}, $client_rec->{firstname}, $client_rec->{lastname}, $client_rec->{email};
         next if $args{-dry_run};
-        _send_verification_email(\%args, $client_rec);
+        _send_verification_email(\%args, $client_rec, $dbh, $orig_sender_email, $sender_email);
     }
 
-    # XXX execute even when we're SIGINT'ed
-    $dbh->do("UPDATE tblconfiguration SET value=? WHERE setting='Email'", {}, $orig_sender_email);
-
     [200];
 }
 
@@ -884,7 +890,7 @@ App::WHMCSUtils - CLI utilities related to WHMCS
 
 =head1 VERSION
 
-This document describes version 0.007 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2019-09-19.
+This document describes version 0.008 of App::WHMCSUtils (from Perl distribution App-WHMCSUtils), released on 2019-09-19.
 
 =head1 FUNCTIONS
 
@@ -1133,6 +1139,10 @@ Whether to include active clients.
 
 Whether to include inactive clients.
 
+=item * B<limit> => I<uint>
+
+Only process this many clients then stop.
+
 =item * B<mech_user_agent> => I<str>
 
 =item * B<random> => I<bool> (default: 1)
